@@ -118,8 +118,8 @@ GitHostGitHub <- R6::R6Class(
     # Check token scopes
     # token parameter only for need of super method
     check_token_scopes = function(response, token = NULL) {
-      private$token_scopes <- response$headers$`x-oauth-scopes` %>%
-        stringr::str_split(", ") %>%
+      private$token_scopes <- response$headers$`x-oauth-scopes` |>
+        stringr::str_split(", ") |>
         unlist()
       org_scopes <- any(private$access_scopes$org %in% private$token_scopes)
       repo_scopes <- any(private$access_scopes$repo %in% private$token_scopes)
@@ -378,7 +378,7 @@ GitHostGitHub <- R6::R6Class(
           )
         }, .progress = set_progress_bar(progress, private))
         names(files_structure_list) <- orgs
-        files_structure_list <- files_structure_list %>%
+        files_structure_list <- files_structure_list |>
           purrr::discard(~ length(.) == 0)
         if (length(files_structure_list) == 0 && verbose) {
           cli::cli_alert_warning(
@@ -395,7 +395,7 @@ GitHostGitHub <- R6::R6Class(
     get_repos_data = function(org, repos = NULL, verbose) {
       cached_repos <- private$get_cached_repos(org)
       if (is.null(cached_repos)) {
-        if (verbose) cli::cli_alert("Pulling repositories data...")
+        if (verbose) cli::cli_alert("[{org}] Pulling repositories data...")
         owner_type <- attr(org, "type") %||% "organization"
         org <- utils::URLdecode(org)
         graphql_engine <- private$engines$graphql
@@ -406,7 +406,7 @@ GitHostGitHub <- R6::R6Class(
         )
         private$set_cached_repos(repos_from_org, org, verbose)
       } else {
-        if (verbose) cli::cli_alert("Using cached repositories data...")
+        if (verbose) cli::cli_alert("[{org}] Using cached repositories data...")
         repos_from_org <- cached_repos
       }
       if (!is.null(repos)) {
