@@ -346,7 +346,7 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
       } else {
         cached_repos <- private$get_cached_repos(org)
         if (is.null(cached_repos)) {
-          if (verbose) cli::cli_alert("Pulling repositories data...")
+          if (verbose) cli::cli_alert("[{org}] Pulling repositories data...")
           graphql_engine <- private$engines$graphql
           owner_type <- attr(org, "type") %||% "organization"
           repos_from_org <- graphql_engine$get_repos_from_org(
@@ -431,7 +431,7 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
           )
         }, .progress = set_progress_bar(progress, private))
         names(files_structure_list) <- orgs
-        files_structure_list <- files_structure_list %>%
+        files_structure_list <- files_structure_list |>
           purrr::discard(~ length(.) == 0)
         if (length(files_structure_list) == 0 && verbose) {
           cli::cli_alert_warning(
