@@ -5,7 +5,7 @@
 #' @return A data.frame.
 #' @examples
 #' \dontrun{
-#'  my_gitstats <- create_gitstats() %>%
+#'  my_gitstats <- create_gitstats() |>
 #'   set_github_host(
 #'     token = Sys.getenv("GITHUB_PAT"),
 #'     orgs = c("r-world-devs", "openpharma")
@@ -17,8 +17,8 @@ get_release_logs <- function(gitstats,
                              since = NULL,
                              until = Sys.Date() + lubridate::days(1),
                              cache = TRUE,
-                             verbose = is_verbose(gitstats),
-                             progress = verbose) {
+                             verbose = FALSE,
+                             progress = TRUE) {
   start_time <- Sys.time()
   if (is.null(since)) {
     cli::cli_abort(cli::col_red("You need to pass date to `since` parameter."), call = NULL)
@@ -32,8 +32,6 @@ get_release_logs <- function(gitstats,
   )
   end_time <- Sys.time()
   time_taken <- end_time - start_time
-  if (verbose) {
-    cli::cli_alert_success("Data pulled in {round(time_taken, 1)} {attr(time_taken, 'units')}")
-  }
+  cli::cli_alert_success("Data pulled in {round(time_taken, 1)} {attr(time_taken, 'units')}")
   return(release_logs)
 }
