@@ -9,11 +9,11 @@
 #'   printing output is switched off.
 #' @examples
 #' \dontrun{
-#'  my_gitstats <- create_gitstats() %>%
+#'  my_gitstats <- create_gitstats() |>
 #'   set_github_host(
 #'     token = Sys.getenv("GITHUB_PAT"),
 #'     orgs = c("r-world-devs")
-#'   ) %>%
+#'   ) |>
 #'   set_gitlab_host(
 #'     token = Sys.getenv("GITLAB_PAT_PUBLIC"),
 #'     orgs = "mbtests"
@@ -24,8 +24,8 @@
 #' @export
 get_users <- function(gitstats,
                       logins,
-                      cache   = TRUE,
-                      verbose = is_verbose(gitstats)) {
+                      cache = TRUE,
+                      verbose = FALSE) {
   start_time <- Sys.time()
   users <- gitstats$get_users(
     logins = logins,
@@ -34,8 +34,6 @@ get_users <- function(gitstats,
   )
   end_time <- Sys.time()
   time_taken <- end_time - start_time
-  if (verbose) {
-    cli::cli_alert_success("Data pulled in {round(time_taken, 1)} {attr(time_taken, 'units')}")
-  }
+  cli::cli_alert_success("Data pulled in {round(time_taken, 1)} {attr(time_taken, 'units')}")
   return(users)
 }
