@@ -31,7 +31,7 @@ cut_item_to_print <- function(item_to_print) {
     list_items <- paste0(item_to_print, collapse = ", ")
   } else {
     item_to_print_cut <- item_to_print[1:10]
-    list_items <- paste0(item_to_print_cut, collapse = ", ") %>%
+    list_items <- paste0(item_to_print_cut, collapse = ", ") |>
       paste0("... and ", length(item_to_print) - 10, " more")
   }
   return(list_items)
