@@ -29,6 +29,17 @@ test_that("get_release_logs works as expected", {
   test_mocker$cache(release_logs_table)
 })
 
+test_that("get_issues gets data from storage for the second time", {
+  expect_snapshot(
+    release_logs_table <- test_gitstats$get_release_logs(
+      since = "2023-08-01",
+      until = "2023-09-30",
+      verbose = FALSE
+    )
+  )  
+  expect_releases_table(release_logs_table)
+})
+
 test_that("get_release_logs returns warning when releases table is empty", {
   mockery::stub(
     test_gitstats$get_release_logs,
