@@ -16,11 +16,11 @@ test_that("GitStats prints the proper info when connections are added.", {
 test_that("GitStats prints the proper info when repos are passed instead of orgs.", {
   skip_on_cran()
   suppressMessages(
-    test_gitstats <- create_gitstats() %>%
+    test_gitstats <- create_gitstats() |>
       set_github_host(
         token = Sys.getenv("GITHUB_PAT"),
         repos = c("r-world-devs/GitStats", "openpharma/GithubMetrics")
-      ) %>%
+      ) |>
       set_gitlab_host(
         token = Sys.getenv("GITLAB_PAT_PUBLIC"),
         repos = c("mbtests/gitstatstesting", "mbtests/gitstats-testing-2")
@@ -58,6 +58,7 @@ test_that("check_if_args_changed", {
   test_gitstats <- create_test_gitstats(
     hosts = 2,
     priv_mode = TRUE,
+    test_mocker = test_mocker,
     inject_repos = "repos_table"
   )
   check <- test_gitstats$check_if_args_changed(
@@ -117,7 +118,7 @@ test_that("show_orgs print orgs properly", {
 test_that("show_orgs print subgroups properly", {
   skip_on_cran()
   suppressMessages(
-    test_gitstats <- create_gitstats() %>%
+    test_gitstats <- create_gitstats() |>
       set_gitlab_host(
         token = Sys.getenv("GITLAB_PAT_PUBLIC"),
         orgs = "mbtests/subgroup"
@@ -132,7 +133,7 @@ test_that("show_orgs print subgroups properly", {
 test_that("subgroups are cleanly printed in GitStats", {
   skip_on_cran()
   suppressMessages(
-    test_gitstats <- create_gitstats() %>%
+    test_gitstats <- create_gitstats() |>
       set_gitlab_host(
         token = Sys.getenv("GITLAB_PAT_PUBLIC"),
         orgs = "mbtests/subgroup"
